#include <qapp.h>
#include <qwidget.h>
#include <qdialog.h>
#include <qscrbar.h>
#include <qpushbt.h>
#include <qtooltip.h>
#include <qframe.h>
#include <qpixmap.h>
#include <qstring.h>
#include <qlabel.h>
#include <qfont.h>
#include "sliderpanel.moc"
#include "mixer.h"
#include "mixer.cc"
#include "images.h"

SliderPanel::SliderPanel(QWidget * parent, const char *name)
:QWidget(parent,name)
{
  QPixmap p_icon (d_icon);			  // build QPixmaps from the XPMs (images.h)
  QPixmap p_background (d_background);
  QPixmap p_master (d_master);
  QPixmap p_line (d_line);
  QPixmap p_cd (d_cd);
  QPixmap p_dsp (d_dsp);
  QPixmap p_synth (d_synth);
  QPixmap p_misc (d_misc);

  // colors for normal buttons:
  QColorGroup normal( QColor( QRgb(0) ), QColor( QRgb(14474460) ), QColor( QRgb(16119285) ), QColor( QRgb(4473924) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
  QColorGroup disabled( QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
  QColorGroup active( QColor( QRgb(0) ), QColor( QRgb(9737364) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
  QPalette normb(normal,disabled,active);

  // colors for active button:
  QColorGroup an(QColor(QRgb(0)), QColor( QRgb(11184860) ), QColor( QRgb(16119295) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
  QColorGroup ad(QColor(QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
  QColorGroup aa(QColor(QRgb(0)), QColor( QRgb(11184830) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
  QPalette activeb(an,ad,aa);

  // colors for the slider:
  QColorGroup sn(QColor( QRgb(255) ), QColor( QRgb(5131854) ), QColor( QRgb(12632256) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(255) ), QColor( QRgb(255) ) );
  QColorGroup sd(QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
  QColorGroup sa(QColor( QRgb(0) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
  QPalette s_palette(sn,sd,sa);

  Volume V;
  int initpos;
  setFixedSize(194, 21);
  setPalette(QPalette(QColor(170,170,170)));	// setting lightgray color palette.
  setFocusPolicy(QWidget::NoFocus);		// disabling [tab] focus.
  V=mixer.read_vol();				// getting master volume.
  initpos=(V.getleft()+V.getright())/2;		
  setCaption("kLo_mix v1.1");
  setIcon(p_icon);
  setIconText("kLo_mix");
    
    scroll=new QSlider(QSlider::Horizontal, this, "scrollbar");
    scroll->setValue(initpos);
    scroll->setRange(0,100);
    scroll->setSteps(1,1);
    scroll->setPalette(s_palette);
    scroll->setBackgroundPixmap(p_background);
    scroll->setFocusPolicy(QWidget::NoFocus);
    connect(scroll,SIGNAL(valueChanged(int)),this, SLOT(setvol(int)));
    setvol(initpos);
    
    b0=new QPushButton(this, "b0");
    b0->setPixmap(p_master);
    b0->setPalette(activeb);
    connect(b0,SIGNAL(clicked()),this, SLOT(bla0()));
    QToolTip::add(b0,"Master");
    b0->setFocusPolicy(QWidget::NoFocus);

    b1=new QPushButton(this, "b1");
    b1->setPixmap(p_line);
    b1->setPalette(normb);
    QToolTip::add(b1,"Line_In");
    connect(b1,SIGNAL(clicked()),this, SLOT(bla1()));
    b1->setFocusPolicy(QWidget::NoFocus);

    b2=new QPushButton(this, "b2");
    b2->setPixmap(p_cd);
    b2->setPalette(normb);
    QToolTip::add(b2,"CD");
    connect(b2,SIGNAL(clicked()),this, SLOT(bla2()));
    b2->setFocusPolicy(QWidget::NoFocus);
    
    b3=new QPushButton(this, "b3");
    b3->setPixmap(p_dsp);
    b3->setPalette(normb);
    QToolTip::add(b3,"DSP/PCM");
    connect(b3,SIGNAL(clicked()),this, SLOT(bla3()));
    b3->setFocusPolicy(QWidget::NoFocus);
    
    b4=new QPushButton(this, "b4");
    b4->setPixmap(p_synth);
    b4->setPalette(normb);
    QToolTip::add(b4,"Synthersizer/FM");
    connect(b4,SIGNAL(clicked()),this, SLOT(bla4()));
    b4->setFocusPolicy(QWidget::NoFocus);
    
    b5=new QPushButton(this, "b5");
    b5->setPixmap(p_misc);
    b5->setPalette(normb);
    QToolTip::add(b5,"Recording Source / About");
    connect(b5,SIGNAL(clicked()),this, SLOT(info()));
    b5->setFocusPolicy(QWidget::NoFocus);
}

void SliderPanel::resizeEvent(QResizeEvent *)		// this is also called at startup.
{
    scroll->setGeometry(1,0,192,9);	// scrollbar
    b0->setGeometry(1,10,37,12);	// master
    b1->setGeometry(40,10,37,12);	// line_in
    b2->setGeometry(79,10,27,12);	// cd
    b3->setGeometry(108,10,27,12);	// dsp
    b4->setGeometry(137,10,37,12);	//synth
    b5->setGeometry(176,10,18,12);	// misc
}

void SliderPanel::setvol(int position)			// setting volume.
{
 int volume=0+position;
 Volume V(volume,volume);  // Create volume variable.
 mixer.write_vol(V);	   // Set the volume.
 QString tooltip;					// setting new tooltip for the slider.
 tooltip.sprintf("Loudness: %d (ch: %d)",position,dev);
 QToolTip::add(scroll,tooltip);
}

void SliderPanel::bla0()
{
setUpdatesEnabled(FALSE);
dev=0;
Volume V;
int initpos;
V=mixer.read_vol();
initpos=(V.getleft()+V.getright())/2;	
scroll->setValue(initpos);
QColorGroup normal( QColor( QRgb(0) ), QColor( QRgb(14474460) ), QColor( QRgb(16119285) ), QColor( QRgb(4473924) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup disabled( QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup active( QColor( QRgb(0) ), QColor( QRgb(9737364) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette normb(normal,disabled,active);
QColorGroup an(QColor(QRgb(0)), QColor( QRgb(11184860) ), QColor( QRgb(16119295) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup ad(QColor(QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup aa(QColor(QRgb(0)), QColor( QRgb(11184830) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette activeb(an,ad,aa);
b0->setPalette(activeb);
b1->setPalette(normb);
b2->setPalette(normb);
b3->setPalette(normb);
b4->setPalette(normb);
setUpdatesEnabled(TRUE);
}

void SliderPanel::bla1()
{
setUpdatesEnabled(FALSE);
dev=6;
Volume V;
int initpos;
V=mixer.read_vol();
initpos=(V.getleft()+V.getright())/2;	
scroll->setValue(initpos);
QColorGroup normal( QColor( QRgb(0) ), QColor( QRgb(14474460) ), QColor( QRgb(16119285) ), QColor( QRgb(4473924) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup disabled( QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup active( QColor( QRgb(0) ), QColor( QRgb(9737364) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette normb(normal,disabled,active);
QColorGroup an(QColor( QRgb(0) ), QColor( QRgb(11184860) ), QColor( QRgb(16119295) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup ad( QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup aa(QColor(QRgb(0)), QColor( QRgb(11184830) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette activeb(an,ad,aa);
b1->setPalette(activeb);
b0->setPalette(normb);
b2->setPalette(normb);
b3->setPalette(normb);
b4->setPalette(normb);
setUpdatesEnabled(TRUE);
}

void SliderPanel::bla2()
{
setUpdatesEnabled(FALSE);
dev=8;
Volume V;
int initpos;
V=mixer.read_vol();
initpos=(V.getleft()+V.getright())/2;	
scroll->setValue(initpos);
QColorGroup normal( QColor( QRgb(0) ), QColor( QRgb(14474460) ), QColor( QRgb(16119285) ), QColor( QRgb(4473924) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup disabled( QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup active( QColor( QRgb(0) ), QColor( QRgb(9737364) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette normb(normal,disabled,active);
QColorGroup an(QColor( QRgb(0) ), QColor( QRgb(11184860) ), QColor( QRgb(16119295) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup ad( QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup aa(QColor(QRgb(0)), QColor( QRgb(11184830) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette activeb(an,ad,aa);
b2->setPalette(activeb);
b1->setPalette(normb);
b0->setPalette(normb);
b3->setPalette(normb);
b4->setPalette(normb);
setUpdatesEnabled(TRUE);
}

void SliderPanel::bla3()
{
setUpdatesEnabled(FALSE);
dev=4;
Volume V;
int initpos;
V=mixer.read_vol();
initpos=(V.getleft()+V.getright())/2;	
scroll->setValue(initpos);
QColorGroup normal( QColor( QRgb(0) ), QColor( QRgb(14474460) ), QColor( QRgb(16119285) ), QColor( QRgb(4473924) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup disabled( QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup active( QColor( QRgb(0) ), QColor( QRgb(9737364) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette normb(normal,disabled,active);
QColorGroup an(QColor( QRgb(0) ), QColor( QRgb(11184860) ), QColor( QRgb(16119295) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup ad( QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup aa(QColor(QRgb(0)), QColor( QRgb(11184830) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette activeb(an,ad,aa);
b3->setPalette(activeb);
b1->setPalette(normb);
b2->setPalette(normb);
b0->setPalette(normb);
b4->setPalette(normb);
setUpdatesEnabled(TRUE);
}

void SliderPanel::bla4()
{
setUpdatesEnabled(FALSE);
dev=3;
Volume V;
int initpos;
V=mixer.read_vol();
initpos=(V.getleft()+V.getright())/2;	
scroll->setValue(initpos);
QColorGroup normal( QColor( QRgb(0) ), QColor( QRgb(14474460) ), QColor( QRgb(16119285) ), QColor( QRgb(4473924) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup disabled( QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup active( QColor( QRgb(0) ), QColor( QRgb(9737364) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette normb(normal,disabled,active);
QColorGroup an(QColor( QRgb(0) ), QColor( QRgb(11184860) ), QColor( QRgb(16119295) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QColorGroup ad(QColor( QRgb(8421504) ), QColor( QRgb(12632256) ), QColor( QRgb(16777215) ), QColor( QRgb(6316128) ), QColor( QRgb(10789024) ), QColor( QRgb(8421504) ), QColor( QRgb(12632256) ) );
QColorGroup aa(QColor(QRgb(0)), QColor( QRgb(11184830) ), QColor( QRgb(4473924) ), QColor( QRgb(16119285) ), QColor( QRgb(10789024) ), QColor( QRgb(0) ), QColor( QRgb(16777215) ) );
QPalette activeb(an,ad,aa);
b4->setPalette(activeb);
b1->setPalette(normb);
b2->setPalette(normb);
b3->setPalette(normb);
b0->setPalette(normb);
setUpdatesEnabled(TRUE);
}


infoscreen::infoscreen(QWidget * parent, const char *name)
:QDialog(parent,name,FALSE,WStyle_Customize|WStyle_DialogBorder)
{
  QPixmap p_background2 (d_background2);
  QPixmap p_icon2 (d_icon);
  setFixedSize(400, 300);
  setBackgroundPixmap(p_background2);
  setFocusPolicy(QWidget::NoFocus);
  setCaption("kLo_mix v1.1 - Recording Source / About");
  
    info_image=new QLabel(this,"info_image");
    info_image->setFrameStyle(QFrame::Panel|QFrame::Sunken);
    info_image->setBackgroundPixmap(p_background2);
    info_image->setPixmap(p_icon2);    
    info_image->setAlignment(AlignCenter);
    info_image->setGeometry(5,5,48,40);
    
    info_text=new QLabel(this,"info_text");
    info_text->setFrameStyle(QFrame::Panel|QFrame::Sunken);
    info_text->setBackgroundPixmap(p_background2);
    info_text->setAlignment(AlignCenter);
    info_text->setText("kLo_mix version 1.1\n(c) 1998 by kLoGraFX / Adam Kopacz <A.K.@gmx.de>");
    info_text->setGeometry(55,5,340,40);
    info_text->setFont(QFont( "helvetica",12));

    fake=new QLabel(this,"fake");
    fake->setFrameStyle(QFrame::Panel|QFrame::Sunken);
    fake->setBackgroundColor(QColor(220,220,220));
    fake->setGeometry(5,50,390,220);

    recsrc=new QLabel(this,"recsrc");
    recsrc->setText("Recording Source:");
    recsrc->setFont(QFont( "helvetica",14));
    recsrc->setAlignment(AlignCenter);
    recsrc->setFrameStyle(QFrame::Panel|QFrame::Raised);
    recsrc->setBackgroundColor(QColor(220,220,220));
    recsrc->setGeometry(125,70,150,20);
    
    rb1=new QCheckBox(this,"rb1");
    rb1->setGeometry(155,100,100,20);
    rb1->setText("Line In");
    rb1->setBackgroundColor(QColor(220,220,220));
    connect(rb1,SIGNAL(clicked()),this, SLOT(srb1()));
    
    rb2=new QCheckBox(this,"rb2");
    rb2->setGeometry(155,122,100,20);
    rb2->setText("Microphone");
    rb2->setBackgroundColor(QColor(220,220,220));
    connect(rb2,SIGNAL(clicked()),this, SLOT(srb2()));
    
    rb3=new QCheckBox(this,"rb3");
    rb3->setGeometry(155,144,100,20);
    rb3->setText("CD");
    rb3->setBackgroundColor(QColor(220,220,220));
    connect(rb3,SIGNAL(clicked()),this, SLOT(srb3()));
    
    mixer.read_input();
    if (finput==1) {
    rb1->setChecked(TRUE); }
    if (finput==2) {
    rb2->setChecked(TRUE); }
    if (finput==3) {
    rb3->setChecked(TRUE); }

    ok=new QLabel(this,"ok");
    ok->setText("Push '...' again to close");
    ok->setAlignment(AlignCenter);
    ok->setFrameStyle(QFrame::Panel|QFrame::Sunken);
    ok->setBackgroundColor(QColor(240,220,220));
    ok->setGeometry(100,275,200,20);
}

void infoscreen::srb1()
{
mixer.write_input_1();
rb1->setChecked(TRUE);
rb2->setChecked(FALSE);
rb3->setChecked(FALSE);
}

void infoscreen::srb2()
{
mixer.write_input_2();
rb1->setChecked(FALSE);
rb2->setChecked(TRUE);
rb3->setChecked(FALSE);
}

void infoscreen::srb3()
{
mixer.write_input_3();
rb1->setChecked(FALSE);
rb2->setChecked(FALSE);
rb3->setChecked(TRUE);
}


void SliderPanel::info()
{
 if (!is) {
    is=new infoscreen;
    isUp = FALSE;
 }
 isUp = !isUp;
    if ( isUp )
        is->show();
    else
	is->hide();
}
